<?php
function _setSelectionTopic(&$tof,$vars) {
	setSelectionTopic($tof,$vars['ParentTopicID']);
}

function setSelectionTopic(&$tof,$topicID) {
	require_once("actions/updatePictures.php");
	$selection = $tof->ct->getSelection($tof->uid);
	updatePictures($tof,$topicID,"unchanged",$selection);
}
?>